package Qt::Gui::QStyleOptionButton;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QStyleOptionButton
# file     : QtGui/qstyleoption.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QStyleOption/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QStyleOptionButton

=head1 PUBLIC METHODS

=over

=item   QStyleOptionButton()

=item   QStyleOptionButton(const QStyleOptionButton & other)


=back

=head1 ENUM VALUES

=over

=item Type

=item Version

=item None

=item Flat

=item HasMenu

=item DefaultButton

=item AutoDefaultButton

=item CommandLinkButton


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
